### Name: ergmm
### Title: Fit a Latent Space Random Graph Model
### Aliases: ergmm
### Keywords: graphs

### ** Examples

#
# See http://statnetproject.org/latentnetHRT
# for more examples
#
# For an explanation and examples of creating 'network' objects
# see the required 'network' package.
#
# Use 'data(package = "latentnetHRT")' to list the data sets in a
#
data(package="latentnetHRT")
#
# Using Sampson's Monk data, lets fit a 
# simple latent position model
#
data(sampson)
#
# Get the group labels
#
group <- get.vertex.attribute(samplike,"group")
samp.labs <- substr(group,1,1)
#
samp.fit <- ergmm(samplike ~ latent(k=2), burnin=10000,
                 MCMCsamplesize=2000, interval=30)
#
# See if we have convergence in the MCMC
mcmc.diagnostics(samp.fit)
#
# Plot the fit
#
plot(samp.fit,label=samp.labs, vertex.col="group")
#
# Using Sampson's Monk data, lets fit a latent clustering model
#
## Not run: 
##D samp.fit <- ergmm(samplike ~ latentcluster(k=2, ngroups=3), burnin=10000,
##D                  MCMCsamplesize=2000, interval=30)
##D #
##D # See if we have convergence in the MCMC
##D mcmc.diagnostics(samp.fit)
##D #
##D # Lets look at the goodness of fit:
##D #
##D plot(samp.fit,label=samp.labs, vertex.col="group")
##D plot(samp.fit,pie=TRUE,label=samp.labs)
##D plot(samp.fit,density=c(2,2))
##D plot(samp.fit,contours=5,contour.color="red")
##D plot(samp.fit,density=TRUE,drawarrows=TRUE)
##D #
##D # Add contours
##D #
##D ergmm.add.contours(samp.fit,nlevels=8,lwd=2)
##D points(samp.fit$Z.mkl,pch=19,col=samp.fit$class)
##D #
##D # Try a covariate on the group
##D #
##D samegroup <- outer(group, group, "==")
##D diag(samegroup) <- 0
##D samp.fit <- ergmm(samplike ~ latentcov(samegroup) + latent(k=2))
##D summary(samp.fit)
## End(Not run)



