### Name: gof.ergmm
### Title: Conduct Goodness-of-Fit Diagnostics on a Latent Position or
###   Latent Cluster Position Model
### Aliases: gof.ergmm gof.default gof
### Keywords: models

### ** Examples

## Not run: 
##D #
##D # Using Sampson's Monk data, lets fit a 
##D # simple latent position model
##D #
##D data(sampson)
##D #
##D # Get the group labels
##D #
##D group <- get.vertex.attribute(samplike,"group")
##D samp.labs <- substr(group,1,1)
##D #
##D # Fit the two-dimensional latent social space model 
##D #
##D # This may take a few minutes ...
##D #
##D samp.fit <- ergmm(samplike ~ latent(k=2), burnin=10000,
##D                   MCMCsamplesize=2000, interval=30)
##D #
##D # Posterior Predictive Checks
##D gofsamplike <- gof.ergmm(samp.fit, GOF=~idegree)
##D gofsamplike
##D #
##D # Place both on the same page
##D # with nice margins
##D #
##D par(mfrow=c(1,2))
##D par(oma=c(0.5,2,1,0.5))
##D #
##D plot(gofsamplike)
##D #
##D # And now the odds 
##D #
##D plot(gofsamplike, plotodds=TRUE)
##D #
##D # Using Sampson's Monk data, lets 
##D # fit the two-dimensional clustered latent social space model 
##D #
##D # The ngroups parameter fits 3 groups
##D #
##D # This may take a few minutes ...
##D #
##D samp.fit <- ergmm(samplike ~ latentcluster(k=2, ngroups=3), burnin=10000,
##D                   MCMCsamplesize=2000, interval=30)
##D #
##D # Posterior Predictive Checks
##D gofsamplike <- gof.ergmm(samp.fit, GOF=~idegree)
##D gofsamplike
##D #
##D plot(gofsamplike)
##D #
##D # And now the odds 
##D #
##D plot(gofsamplike, plotodds=TRUE)
## End(Not run)



